typed_descriptors.prop
======================

.. automodule:: typed_descriptors.prop

Prop
----

.. autoclass:: typed_descriptors.prop.Prop
    :show-inheritance:
    :members:
    :special-members: __init__, __get__

T_co
----

.. autodata:: typed_descriptors.prop.T_co

ValueFunction
-------------

.. autoclass:: typed_descriptors.prop.ValueFunction
    :show-inheritance:
    :members:
